@@ -23,8 +23,6 @@ int main(int argc, char *argv[])
 {
     qSetMessagePattern(QStringLiteral("%{function}() : %{message}\n"));
 
-    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication::setOrganizationName(QStringLiteral("KDE"));
     QApplication::setApplicationName(QStringLiteral("Haruna"));
     QApplication::setOrganizationDomain(QStringLiteral("kde.org"));
@@ -53,7 +51,7 @@ int main(int argc, char *argv[])
             QCommandLineParser clParser;
             clParser.process(qApplication);
             if (clParser.positionalArguments().size() > 0) {
-                QString file = clParser.positionalArguments().first();
+                QString file = clParser.positionalArguments().constFirst();
                 kdsApp.sendMessage(file.toUtf8());
             }
             exit(EXIT_SUCCESS);
@@ -61,14 +59,13 @@ int main(int argc, char *argv[])
     }
 
     QQmlApplicationEngine engine(&qApplication);
-    const QUrl url(QStringLiteral("qrc:/qml/main.qml"));
+    const QUrl url(QStringLiteral("qrc:/qt/qml/org/kde/haruna/qml/main.qml"));
     auto onObjectCreated = [url](const QObject *obj, const QUrl &objUrl) {
         if (!obj && url == objUrl) {
             QCoreApplication::exit(-1);
         }
     };
     QObject::connect(&engine, &QQmlApplicationEngine::objectCreated, &qApplication, onObjectCreated, Qt::QueuedConnection);
-    engine.addImportPath(QStringLiteral("qrc:/qml"));
     engine.addImageProvider(QStringLiteral("thumbnail"), new ThumbnailImageProvider());
     engine.rootContext()->setContextProperty(QStringLiteral("app"), Application::instance());
     engine.rootContext()->setContextProperty(QStringLiteral("appActions"), new QQmlPropertyMap);
