@@ -5,12 +5,12 @@
  */
 
 #include "subtitlesfoldersmodel.h"
-#include "subtitlessettings.h"
 
 #include <KConfig>
-#include <KConfigDialog>
 #include <KConfigGroup>
-#include <global.h>
+
+#include "global.h"
+#include "subtitlessettings.h"
 
 SubtitlesFoldersModel::SubtitlesFoldersModel(QObject *parent)
     : QAbstractListModel(parent)
