@@ -9,12 +9,13 @@
 
 #include <QAbstractListModel>
 #include <QObject>
-
-#include "track.h"
+#include <QtQml/qqmlregistration.h>
 
 class TracksModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(TracksModel)
+
 public:
     explicit TracksModel(QObject *parent = nullptr);
     enum { TextRole = Qt::UserRole, LanguageRole, TitleRole, IDRole, CodecRole };
@@ -23,10 +24,10 @@ public:
     virtual QHash<int, QByteArray> roleNames() const override;
 
 public Q_SLOTS:
-    void setTracks(QMap<int, Track *> tracks);
+    void setTracks(QList<QVariant> tracks);
 
 private:
-    QMap<int, Track *> m_tracks;
+    QList<QVariant> m_tracks;
 };
 
 #endif // TRACKSMODEL_H
