@@ -7,14 +7,17 @@
 #ifndef MPVPREVIEW_H
 #define MPVPREVIEW_H
 
-#include "mpvabstractitem.h"
+#include <MpvAbstractItem>
 
 class MpvRenderer;
 
 class MpvPreview : public MpvAbstractItem
 {
     Q_OBJECT
+    QML_ELEMENT
+
     Q_PROPERTY(double position READ position WRITE setPosition NOTIFY positionChanged)
+    Q_PROPERTY(double aspectRatio READ aspectRatio NOTIFY aspectRatioChanged)
     Q_PROPERTY(QString file READ file WRITE setFile NOTIFY fileChanged)
     Q_PROPERTY(bool accuratePreview READ accuratePreview WRITE setAccuratePreview NOTIFY accuratePreviewChanged)
     Q_PROPERTY(bool isLocalFile READ isLocalFile WRITE setIsLocalFile NOTIFY isLocalFileChanged)
@@ -25,6 +28,8 @@ public:
     double position();
     void setPosition(double value);
 
+    double aspectRatio();
+
     QString file() const;
     void setFile(const QString &_file);
 
@@ -38,17 +43,17 @@ public:
 
 Q_SIGNALS:
     void positionChanged();
+    void aspectRatioChanged();
     void fileChanged();
-
     void accuratePreviewChanged();
-
     void isLocalFileChanged();
 
 private:
     double m_position{0.0};
     QString m_file;
-    bool m_accuratePreview;
+    bool m_accuratePreview{false};
     bool m_isLocalFile{false};
+    bool m_isReady{false};
 };
 
 #endif // MPVPREVIEW_H
